@@ -720,6 +720,8 @@ class NREN
 				if (Config::get_config('debug')) {
 					echo "no IdP with name (".$this->idp_name.") found in db!<br />\n";
 				}
+				Logger::log_event(LOG_NOTICE, "Could not find NREN-map for idp " . $this->idp_name .
+						  ". Is the NREN bootstrapped properly?");
 				return false;
 			case 1:
 				/* decorate NREN */
